@@ -13,7 +13,7 @@
 #' as.magpie,numeric-method as.magpie,NULL-method as.magpie,quitte-method
 #' as.magpie,tbl_df-method
 #' is.magpie [,magpie-method [,magpie,ANY,ANY-method [<-,magpie,ANY,ANY-method
-#' [<-,magpie-method Ops,magpie,magpie-method
+#' [<-,magpie-method Ops,magpie,magpie-method Ops,magpie,numeric-method Ops,numeric,magpie-method
 #' @docType class
 #' @param x An object that should be either tested or transformed as/to an
 #' MAgPIE-object.
@@ -193,9 +193,11 @@ setMethod("[",
               if(is.factor(j)) j <- as.character(j)
               if(is.numeric(j) & any(j>dim(x)[2])) {
                 j <- paste("y",j,sep="")
-                if(invert) j <- getYears(x)[!(getYears(x) %in% j)]
-              } else if(is.null(j)) {
+              }
+              if(is.null(j)) {
                 j <- 1:dim(x)[2]
+              } else if(is.character(j) && grepl(".",dimnames(x)[[2]][1],fixed=TRUE)) {
+                j <- .dimextract(x,j,2,pmatch=pmatch,invert=invert)
               } else if(invert) {
                 j <- getYears(x)[!(getYears(x) %in% j)]
               }
@@ -250,6 +252,7 @@ setMethod("[<-",
               if(is.factor(j)) j <- as.character(j)
               if(is.numeric(j) & any(j>dim(x)[2])) j <- paste("y",j,sep="")
               else if(is.null(j)) j <- 1:dim(x)[2]
+              else if(is.character(j) && grepl(".",dimnames(x)[[2]][1],fixed=TRUE)) j <- .dimextract(x,j,2,pmatch=pmatch) 
             }
             if(!missing(k)) {
               if(is.factor(k)) k <- as.character(k)
@@ -271,6 +274,7 @@ setMethod("[<-",
                 if(getOption("magclass.verbosity")>1) cat("NOTE ([<-): Dangerous replacement! As replacement value is not an MAgPIE object name checking is deactivated!\n")
               }
               x@.Data[i,j,k] <- value
+              if (!is.null(getMetadata(value,"calcHistory"))) x <- updateMetadata(x,value,n=2,calcHistory="merge",cH_priority=4)
               return(x)
             }
           }
